/**
 * This export is a variant of the quickjs WASM library:
 * ### [@jitl/quickjs-node-cjs-release-sync-wasm](https://github.com/justjake/quickjs-emscripten/blob/main/doc/packages/@jitl/quickjs-node-cjs-release-sync-wasm/README.md)
 *
 * Node.js CommonJS module
 *
 * | Variable            |    Setting                     |    Description    |
 * | --                  | --                             | --                |
 * | releaseMode         | release | Optimized for performance; use when building/deploying your application. |
 * | syncMode            | sync | The default, normal build. Note that both variants support regular async functions. |
 * | moduleSystem        | commonjs | This variant exports a CommonJS module, which is faster to load and run in Node.js. |
 * | emscriptenInclusion | wasm | Has a separate .wasm file. May offer better caching in your browser, and reduces the size of your JS bundle. If you have issues, try a 'singlefile' variant. |
 *
 */
declare const variant: {
    readonly type: "sync";
    readonly importFFI: () => Promise<typeof import("./ffi.js").QuickJSFFI | (new (module: import("@jitl/quickjs-ffi-types").QuickJSEmscriptenModule) => import("@jitl/quickjs-ffi-types").QuickJSFFI)>;
    readonly importModuleLoader: () => Promise<typeof import("./emscripten-module.js") | import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSEmscriptenModule> | {
        default: import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSEmscriptenModule>;
    } | {
        default: {
            default: import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSEmscriptenModule>;
        };
    }>;
};
export default variant;
